@@ -47,7 +47,7 @@ func TestExecute(t *testing.T) {
 		c.Assert(resp.Err, qt.IsNil)
 		result := resp.Result
 		c.Assert(len(result.Sites) == 1, qt.Equals, true)
-		c.Assert(len(result.Sites[0].RegularPages()) == 1, qt.Equals, true)
+		c.Assert(len(result.Sites[0].RegularPages()) == 2, qt.Equals, true)
 		c.Assert(result.Sites[0].Info.Params()["myparam"], qt.Equals, "paramproduction")
 	})
 
@@ -362,11 +362,20 @@ weight: 1
 
 Content
 
+`)
+
+	writeFile(t, filepath.Join(dir, contentDir, "hügö.md"), `
+---
+weight: 2
+---
+
+This is hügö.
+
 `)
 
 	writeFile(t, filepath.Join(dir, "layouts", "_default", "single.html"), `
 
-Single: {{ .Title }}
+Single: {{ .Title }}|{{ .Content }}
 
 `)
 
