@@ -110,7 +110,7 @@ func (f ContentFactory) SectionFromFilename(filename string) (string, error) {
 
 // CreateContentPlaceHolder creates a content placeholder file inside the
 // best matching content directory.
-func (f ContentFactory) CreateContentPlaceHolder(filename string) (string, error) {
+func (f ContentFactory) CreateContentPlaceHolder(filename string, force bool) (string, error) {
 	filename = filepath.Clean(filename)
 	_, abs, err := f.h.AbsProjectContentDir(filename)
 
@@ -130,6 +130,9 @@ _build:
 
 `
 
+	if force {
+		return abs, afero.WriteReader(f.h.Fs.Source, abs, strings.NewReader(placeholder))
+	}
 	return abs, afero.SafeWriteReader(f.h.Fs.Source, abs, strings.NewReader(placeholder))
 }
 
