@@ -19,7 +19,7 @@ import (
 	"strconv"
 	"strings"
 
-	"github.com/alecthomas/chroma/formatters/html"
+	"github.com/alecthomas/chroma/v2/formatters/html"
 	"github.com/spf13/cast"
 
 	"github.com/gohugoio/hugo/config"
@@ -72,6 +72,9 @@ type Config struct {
 	// A space separated list of line numbers, e.g. “3-8 10-20”.
 	Hl_Lines string
 
+	// If set, the markup will not be wrapped in any container.
+	Hl_inline bool
+
 	// A parsed and ready to use list of line ranges.
 	HL_lines_parsed [][2]int `json:"-"`
 
@@ -93,6 +96,7 @@ func (cfg Config) ToHTMLOptions() []html.Option {
 		html.LineNumbersInTable(cfg.LineNumbersInTable),
 		html.WithClasses(!cfg.NoClasses),
 		html.LinkableLineNumbers(cfg.AnchorLineNos, lineAnchors),
+		html.InlineCode(cfg.Hl_inline),
 	}
 
 	if cfg.Hl_Lines != "" || cfg.HL_lines_parsed != nil {
