@@ -7,7 +7,7 @@ import (
 // This is is just some helpers used to create some JSON used in the Hugo docs.
 func init() {
 	docsProvider := func() docshelper.DocProvider {
-		return docshelper.DocProvider{"media": map[string]interface{}{"types": DefaultTypes}}
+		return docshelper.DocProvider{"media": map[string]any{"types": DefaultTypes}}
 	}
 	docshelper.AddDocProviderFunc(docsProvider)
 }
