@@ -25,8 +25,6 @@ import (
 	"github.com/spf13/cast"
 )
 
-var sortComp = compare.New(true)
-
 // Sort returns a sorted sequence.
 func (ns *Namespace) Sort(seq any, args ...any) (any, error) {
 	if seq == nil {
@@ -51,7 +49,7 @@ func (ns *Namespace) Sort(seq any, args ...any) (any, error) {
 	collator := langs.GetCollator(ns.deps.Language)
 
 	// Create a list of pairs that will be used to do the sort
-	p := pairList{Collator: collator, SortAsc: true, SliceType: sliceType}
+	p := pairList{Collator: collator, sortComp: ns.sortComp, SortAsc: true, SliceType: sliceType}
 	p.Pairs = make([]pair, seqv.Len())
 
 	var sortByField string
@@ -145,6 +143,7 @@ type pair struct {
 // A slice of pairs that implements sort.Interface to sort by Value.
 type pairList struct {
 	Collator  *langs.Collator
+	sortComp  *compare.Namespace
 	Pairs     []pair
 	SortAsc   bool
 	SliceType reflect.Type
@@ -159,16 +158,16 @@ func (p pairList) Less(i, j int) bool {
 	if iv.IsValid() {
 		if jv.IsValid() {
 			// can only call Interface() on valid reflect Values
-			return sortComp.LtCollate(p.Collator, iv.Interface(), jv.Interface())
+			return p.sortComp.LtCollate(p.Collator, iv.Interface(), jv.Interface())
 		}
 
 		// if j is invalid, test i against i's zero value
-		return sortComp.LtCollate(p.Collator, iv.Interface(), reflect.Zero(iv.Type()))
+		return p.sortComp.LtCollate(p.Collator, iv.Interface(), reflect.Zero(iv.Type()))
 	}
 
 	if jv.IsValid() {
 		// if i is invalid, test j against j's zero value
-		return sortComp.LtCollate(p.Collator, reflect.Zero(jv.Type()), jv.Interface())
+		return p.sortComp.LtCollate(p.Collator, reflect.Zero(jv.Type()), jv.Interface())
 	}
 
 	return false
