@@ -69,6 +69,7 @@ func newPrefixState() []*prefix {
 	return []*prefix{
 		{b: []byte("src="), f: checkCandidateBase},
 		{b: []byte("href="), f: checkCandidateBase},
+		{b: []byte("url="), f: checkCandidateBase},
 		{b: []byte("action="), f: checkCandidateBase},
 		{b: []byte("srcset="), f: checkCandidateSrcset},
 	}
@@ -130,7 +131,6 @@ func (l *absurllexer) posAfterURL(q []byte) int {
 	return bytes.IndexFunc(l.content[l.pos:], func(r rune) bool {
 		return r == '>' || unicode.IsSpace(r)
 	})
-
 }
 
 // handle URLs in srcset.
@@ -187,7 +187,6 @@ func checkCandidateSrcset(l *absurllexer) {
 
 	l.pos += len(section)
 	l.start = l.pos
-
 }
 
 // main loop
@@ -230,12 +229,12 @@ func (l *absurllexer) replace() {
 }
 
 func doReplace(path string, ct transform.FromTo, quotes [][]byte) {
-
 	lexer := &absurllexer{
 		content: ct.From().Bytes(),
 		w:       ct.To(),
 		path:    []byte(path),
-		quotes:  quotes}
+		quotes:  quotes,
+	}
 
 	lexer.replace()
 }
@@ -248,7 +247,8 @@ type absURLReplacer struct {
 func newAbsURLReplacer() *absURLReplacer {
 	return &absURLReplacer{
 		htmlQuotes: [][]byte{[]byte("\""), []byte("'")},
-		xmlQuotes:  [][]byte{[]byte("&#34;"), []byte("&#39;")}}
+		xmlQuotes:  [][]byte{[]byte("&#34;"), []byte("&#39;")},
+	}
 }
 
 func (au *absURLReplacer) replaceInHTML(path string, ct transform.FromTo) {
